@@ -21,6 +21,7 @@ use warnings;
 use strict;
 use Perl6::Pod::Block;
 use base 'Perl6::Pod::Block';
+
 =head2 get_attr [code_name]
 
 Return formatting code  attributes splited with pre-configured via =config.
@@ -30,14 +31,16 @@ Unless provided <code_name> return attributes for current .
 
 sub get_attr {
     my $self = shift;
-    my $name =  shift || $self->local_name;
-    $self->SUPER::get_attr($name.'<>')
- 
-}
-
-sub on_para {
-    my ($self ,$parser, $txt) = @_;
-    return $self->SUPER::on_para($parser,$txt)
+    my $attr = $self->SUPER::get_attr;
+    #union attr with =config
+    if (my $ctx = $self->context) {
+        if ( my $config = $ctx->get_config( $self->name . '<>' ) ) {
+         while ( my ($k, $v) = each %$config ) {
+            $attr->{$k} = $v
+           }
+         }
+    }
+    $attr;
 }
 
 1;
